#
#!/bin/sh
#
# Created by Yongjia Niu <ahnniu@gmail.com>
#

BSP_TMP_HOME_PATH=$(dirname $(realpath $0))
CONFIG_FILE=$(lsblk | grep mmcblk0p1 |sed 's/^.*part //')/config.txt
BOOT_PATH=$(lsblk | grep mmcblk0p1 |sed 's/^.*part //')
BSP_TMP_ROOTFS_PATH=$BSP_TMP_HOME_PATH/rootfs


config_set() {
    local key="$1"
    local value="$2"
    local conf="$CONFIG_FILE"

    ${BSP_TMP_HOME_PATH}/raspi-conf.sh set $key $value $conf
}

set_antenna() {
    local conf="$CONFIG_FILE"
    local ant2="dtparam=ant2"

    grep -q "#.*${ant2}" $conf
    if [ $? -eq 0 ];then
        sed -i "s/#.*${ant2}/${ant2}/" $conf
    else
        echo "${ant2}" >> $conf
    fi
}

config_clear() {
    local key="$1"
    local conf="$CONFIG_FILE"

    ${BSP_TMP_HOME_PATH}/raspi-conf.sh clear $key $conf
}

config_get() {
    local key="$1"
    local conf="$CONFIG_FILE"

    ${BSP_TMP_HOME_PATH}/raspi-conf.sh get $key $conf
}

config_overlay_set() {
    local dtbo="$1"
    local params="$2"
    local conf="$CONFIG_FILE"

    ${BSP_TMP_HOME_PATH}/raspi-conf.sh overlay_set $dtbo $conf $params
}

config_overlay_clear() {
    local dtbo="$1"
    local conf="$CONFIG_FILE"

    ${BSP_TMP_HOME_PATH}/raspi-conf.sh overlay_clear $dtbo $conf
}

config_overlay_rm() {
    local dtbo="$1"
    local conf="$CONFIG_FILE"

    ${BSP_TMP_HOME_PATH}/raspi-conf.sh overlay_remove $dtbo $conf
}

do_config() {
    # config_overlay_clear vc4-fkms-v3d
    config_set dtparam=i2c_vc on
    # config_set disable_touchscreen 1
    config_set otg_mode 1
    set_antenna
    # config_set lcd_rotate 2
    # config_overlay_set ed-edt-ft5406
    config_overlay_set i2c-rtc pcf8563,i2c_csi_dsi
    # config_overlay_rm sdio
    config_overlay_set ed-sdhost
}

do_install_overlay() {
    local dst=$BOOT_PATH/overlays
    local src=$BSP_TMP_ROOTFS_PATH/boot/overlays

    install -m 755 $src/* $dst/
}

do_install_dt_blob() {
    local dst=$BOOT_PATH
    local src=$BSP_TMP_ROOTFS_PATH/boot/dt-blob.bin

    install -m 755 $src $dst/
}

echo "Do intall dtbs..."
do_install_overlay
do_install_dt_blob

echo "Do config: [$CONFIG_FILE]..."
do_config

exit 0
